# Sample Layouts

## Qwerty-ANSI

The standard Qwerty-US layout.

## Qwerty-intl

Same layout, but ``'"^`~`` are turned into dead keys:

- `"`, `a` = ä
- `'`, `e` = è

## Qwerty-prog

A qwerty-intl variant with an AltGr layer for dead diacritics and coding symbols.

- `AltGr`+`a` = {
- `AltGr`+`s` = [
- `AltGr`+`d` = ]
- `AltGr`+`f` = }
- `AltGr`+`"`, `a` = ä
- `AltGr`+`'`, `e` = è

## See Also…

- [“One Dead Key”](https://github.com/OneDeadKey/1dk)
